Index: net/cookies/cookie_monster.cc |
diff --git a/net/cookies/cookie_monster.cc b/net/cookies/cookie_monster.cc |
index e090095c97422d3725a25e982571421ac478a4ee..9937ab821a9a9b3ecdcafc04b81aeda23086a0dd 100644 |
--- a/net/cookies/cookie_monster.cc |
+++ b/net/cookies/cookie_monster.cc |
@@ -256,38 +256,38 @@ CookieMonster::CookieItVector::iterator LowerBoundAccessDate( |
LowerBoundAccessDateComparator); |
} |
// Mapping between DeletionCause and Delegate::ChangeCause; the mapping also |
// provides a boolean that specifies whether or not an OnCookieChanged |
// notification ought to be generated. |
typedef struct ChangeCausePair_struct { |
- CookieMonster::Delegate::ChangeCause cause; |
+ CookieMonsterDelegate::ChangeCause cause; |
bool notify; |
} ChangeCausePair; |
ChangeCausePair ChangeCauseMapping[] = { |
// DELETE_COOKIE_EXPLICIT |
- { CookieMonster::Delegate::CHANGE_COOKIE_EXPLICIT, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EXPLICIT, true }, |
// DELETE_COOKIE_OVERWRITE |
- { CookieMonster::Delegate::CHANGE_COOKIE_OVERWRITE, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_OVERWRITE, true }, |
// DELETE_COOKIE_EXPIRED |
- { CookieMonster::Delegate::CHANGE_COOKIE_EXPIRED, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EXPIRED, true }, |
// DELETE_COOKIE_EVICTED |
- { CookieMonster::Delegate::CHANGE_COOKIE_EVICTED, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EVICTED, true }, |
// DELETE_COOKIE_DUPLICATE_IN_BACKING_STORE |
- { CookieMonster::Delegate::CHANGE_COOKIE_EXPLICIT, false }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EXPLICIT, false }, |
// DELETE_COOKIE_DONT_RECORD |
- { CookieMonster::Delegate::CHANGE_COOKIE_EXPLICIT, false }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EXPLICIT, false }, |
// DELETE_COOKIE_EVICTED_DOMAIN |
- { CookieMonster::Delegate::CHANGE_COOKIE_EVICTED, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EVICTED, true }, |
// DELETE_COOKIE_EVICTED_GLOBAL |
- { CookieMonster::Delegate::CHANGE_COOKIE_EVICTED, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EVICTED, true }, |
// DELETE_COOKIE_EVICTED_DOMAIN_PRE_SAFE |
- { CookieMonster::Delegate::CHANGE_COOKIE_EVICTED, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EVICTED, true }, |
// DELETE_COOKIE_EVICTED_DOMAIN_POST_SAFE |
- { CookieMonster::Delegate::CHANGE_COOKIE_EVICTED, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EVICTED, true }, |
// DELETE_COOKIE_EXPIRED_OVERWRITE |
- { CookieMonster::Delegate::CHANGE_COOKIE_EXPIRED_OVERWRITE, true }, |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EXPIRED_OVERWRITE, true }, |
// DELETE_COOKIE_LAST_ENTRY |
- { CookieMonster::Delegate::CHANGE_COOKIE_EXPLICIT, false } |
+ { CookieMonsterDelegate::CHANGE_COOKIE_EXPLICIT, false } |
}; |
std::string BuildCookieLine(const CanonicalCookieVector& cookies) { |
@@ -311,7 +311,8 @@ std::string BuildCookieLine(const CanonicalCookieVector& cookies) { |
// static |
bool CookieMonster::default_enable_file_scheme_ = false; |
-CookieMonster::CookieMonster(PersistentCookieStore* store, Delegate* delegate) |
+CookieMonster::CookieMonster(PersistentCookieStore* store, |
+ CookieMonsterDelegate* delegate) |
: initialized_(false), |
loaded_(false), |
store_(store), |
@@ -327,7 +328,7 @@ CookieMonster::CookieMonster(PersistentCookieStore* store, Delegate* delegate) |
} |
CookieMonster::CookieMonster(PersistentCookieStore* store, |
- Delegate* delegate, |
+ CookieMonsterDelegate* delegate, |
int last_access_threshold_milliseconds) |
: initialized_(false), |
loaded_(false), |
@@ -1680,7 +1681,7 @@ void CookieMonster::InternalInsertCookie(const std::string& key, |
cookies_.insert(CookieMap::value_type(key, cc)); |
if (delegate_.get()) { |
delegate_->OnCookieChanged( |
*cc, false, CookieMonster::Delegate::CHANGE_COOKIE_EXPLICIT); |
} |
} |
@@ -256,38 +256,38 @@ CookieMonster::CookieItVector::iterator LowerBoundAccessDate( |
LowerBoundAccessDateComparator); |
} |
-// Mapping between DeletionCause and Delegate::ChangeCause; the mapping also |
-// provides a boolean that specifies whether or not an OnCookieChanged |
-// notification ought to be generated. |
+// Mapping between DeletionCause and CookieMonsterDelegate::ChangeCause; the |
+// mapping also provides a boolean that specifies whether or not an |
+// OnCookieChanged notification ought to be generated. |
typedef struct ChangeCausePair_struct { |
@@ -1680,7 +1681,7 @@ void CookieMonster::InternalInsertCookie(const std::string& key, |
if (delegate_.get()) { |
delegate_->OnCookieChanged( |
- *cc, false, CookieMonster::Delegate::CHANGE_COOKIE_EXPLICIT); |
+ *cc, false, CookieMonsterDelegate::CHANGE_COOKIE_EXPLICIT); |
} |
} |